@@ -53,6 +53,7 @@ class API(object):
     def __init__(self, import_name, app=None, db=None, *args, **kwargs):
         """ Create an new flask-json-resource API.
         """
+        self.resources = []
         self.blueprint = Blueprint('json_resource', import_name)
 
         resources.Schema.register_schema_dir(
@@ -87,6 +88,20 @@ class API(object):
 
         app.register_blueprint(self.blueprint)
 
+        with app.app_context():
+            background = not app.debug
+
+            for resource in self.resources:
+                if not hasattr(resource, 'indexes'):
+                    continue
+
+                for index in resource.indexes:
+                    resource.collection().ensure_index(
+                        index['key'],
+                        unique=index.get('unique'),
+                        background=background
+                    )
+
         self.mongo = mongo
 
     @property
@@ -114,6 +129,8 @@ class API(object):
             schema = Schema({'id': 'test-resource'})
         """
         def _register(resource_cls):
+            self.resources.append(resource_cls)
+
             _views = views or resource_cls.default_views
 
             for view in _views:
