@@ -3,7 +3,8 @@ from .main import app, Message
 
 
 def before_all(context):
-    context.live_server = LiveServer(app)
+    context.app = app
+    context.live_server = LiveServer(context.app)
     context.live_server.start()
 
     context.url = context.live_server.url
@@ -15,8 +16,9 @@ def after_all(context):
 
 def before_scenario(context, scenario):
     context.headers = {}
+    context.htt_mocks = []
 
 
 def after_scenario(context, scenario):
-    with app.app_context():
+    with context.app.app_context():
         Message.objects.collection.remove()
